@@ -92,6 +92,10 @@ class DebugToolbarMiddleware(object):
 
             toolbar = DebugToolbar(request)
             for panel in toolbar.panels:
+                panel.disabled = panel.dom_id() in request.COOKIES
+                panel.enabled = not panel.disabled
+                if panel.disabled:
+                    continue
                 panel.process_request(request)
             self.__class__.debug_toolbars[threading.current_thread().ident] = toolbar
 
@@ -102,6 +106,8 @@ class DebugToolbarMiddleware(object):
             return
         result = None
         for panel in toolbar.panels:
+            if panel.disabled:
+                continue
             response = panel.process_view(request, view_func, view_args, view_kwargs)
             if response:
                 result = response
@@ -128,6 +134,8 @@ class DebugToolbarMiddleware(object):
         if ('gzip' not in response.get('Content-Encoding', '') and
                 response.get('Content-Type', '').split(';')[0] in _HTML_TYPES):
             for panel in toolbar.panels:
+                if panel.disabled:
+                    continue
                 panel.process_response(request, response)
             response.content = replace_insensitive(
                 force_text(response.content, encoding=settings.DEFAULT_CHARSET),
